# HG changeset patch
# User Dan Drogichen <chirp.cordless@xoxy.net>
# Date 1398717517 25200
#      Mon Apr 28 13:38:37 2014 -0700
# Node ID 9ced1f5eae170ec93599ddec089bb610a7a51d6b
# Parent  e51624d6ad4b7cb72a3554356d71f26cfe503adb
[csv] Friendlier defaults for missing cToneFreq/rToneFreq columns in csv import - Fixes #1577

Add a _clean_tmode() function to the generic CSVRadio class in generic_csv.py.
Check for the existence of csv headings "rToneFreq" and "cToneFreq" in the
header line. If exactly one is present, use the value in that column
for both rTone and cTone for each channel imported.

#1577

diff -r e51624d6ad4b -r 9ced1f5eae17 chirp/generic_csv.py
--- a/chirp/generic_csv.py	Sat Apr 12 10:45:09 2014 -0700
+++ b/chirp/generic_csv.py	Mon Apr 28 13:38:37 2014 -0700
@@ -78,6 +78,8 @@
     def __init__(self, pipe):
         chirp_common.FileBackedRadio.__init__(self, None)
         self.memories = []
+        self.file_has_rTone = None  # Set in load(), used in _clean_tmode()
+        self.file_has_cTone = None
 
         self._filename = pipe
         if self._filename and os.path.exists(self._filename):
@@ -119,6 +121,17 @@
         
         return mem
 
+    def _clean_tmode(self, headers, line, mem):
+        """ If there is exactly one of [rToneFreq, cToneFreq] columns in the
+        csv file, use it for both rtone & ctone. Makes TSQL use friendlier."""
+
+        if self.file_has_rTone and not self.file_has_cTone:
+            mem.ctone = mem.rtone
+        elif self.file_has_cTone and not self.file_has_rTone:
+            mem.rtone = mem.ctone
+
+        return mem
+
     def _parse_csv_data_line(self, headers, line):
         mem = chirp_common.Memory()
         try:
@@ -168,6 +181,8 @@
             lineno += 1
             if lineno == 1:
                 header = line
+                self.file_has_rTone = "rToneFreq" in header
+                self.file_has_cTone = "cToneFreq" in header
                 continue
 
             if len(header) > len(line):
